@@ -71,8 +71,8 @@ class BusinessSalesPrediction(SnsVisualization):
         df = pd.DataFrame(self.df2.index, columns=['区县'], index=self.df2.index)
         for business in self.df1.index:
             # 包含“市辖区”字段的商圈有一个或多个区县，不包含的只有一个区县
-            if "市辖区" in business:
-                business_parse = re.split(r'[（、）]', business)[1:-1]
+            if "（" in business:
+                business_parse = re.split(r'[（、，）]', business)[1:-1]
                 try:
                     df.loc[:, business] = self.df2.loc[:, business_parse].sum(axis=1)
                 except Exception as err:
@@ -83,6 +83,7 @@ class BusinessSalesPrediction(SnsVisualization):
         df.set_index("区县", inplace=True)
         df = df.T
         df = pd.concat([df, self.df1[self.sale_tag]], axis=1, join='inner')
+        df.index.set_names("商圈", inplace=True)
         df.to_excel(self.sales_mapping_file)
         return df
 
@@ -174,7 +175,7 @@ class BusinessSalesPrediction(SnsVisualization):
             df_train_summary["type"] = "training"
             df_test_summary["type"] = "test"
             df_summary = df_train_summary.append(df_test_summary)
-            df_summary.index.set_names("商圈", inplace=True)
+            #df_summary.index.set_names("商圈", inplace=True)
             df_summary.sort_index(inplace=True)  # 按索引(即商圈名字)进行排序
             df_summary['商圈编号'] = np.arange(1, len(df_summary) + 1)  # data_visualization函数需商圈编号
             self.data_file = "summary_%s_%s.xlsx" % (mutil_tag, self.time_tag)
@@ -202,7 +203,7 @@ def ensemble_learning(work_dir, df, sales_file_proc, ocm_file, time_tag, sale_ta
         os.mkdir("history")
     if not os.path.exists(time_tag):
         os.mkdir(time_tag)
-    df = pd.read_excel(sales_mapping_file)
+    df = pd.read_excel(sales_mapping_file, index_col=0)
     parameter = feature_extraction(feature_file)
     df = df.loc[:, parameter + [sale_tag]]
     # 对缺失值进行填充
@@ -260,7 +261,7 @@ def ensemble_learning(work_dir, df, sales_file_proc, ocm_file, time_tag, sale_ta
     df_factor.to_excel(os.path.join(time_tag, '%s_正负因子.xlsx' % time_tag))  # 排名前五的正因子
 
 
-def data_visualization(work_dir, time_tag, sale_tag):
+def data_visualization(work_dir, time_tag, sale_tag, sales_file_proc, province):
     data_file1 = os.path.join(time_tag, "%s_weight_heatmap.xlsx" % time_tag)
     data_file2 = os.path.join(time_tag, "%s_weight_boxplot.xlsx" % time_tag)
     data_file3 = os.path.join(time_tag, "%s_all.xlsx" % time_tag)
@@ -299,7 +300,7 @@ def data_visualization(work_dir, time_tag, sale_tag):
     plt.savefig(os.path.join(time_tag, '%s_商圈预估销量偏移.png' % time_tag), dpi=120, bbox_inches='tight')
     plt.close()
     # 箱线图-散点图解释商圈需要调整的原因
-    adjustment_interpreter.interpreter(time_tag, sale_tag)
+    adjustment_interpreter.interpreter(time_tag, sale_tag, sales_file_proc, province)
 
 
 def main(work_dir, province, sales_file_ori, sales_file_proc, ocm_file, feature_file):
@@ -312,16 +313,15 @@ def main(work_dir, province, sales_file_ori, sales_file_proc, ocm_file, feature_
     sale_data = pd.read_excel(os.path.join(work_dir, sales_file_proc), index_col=0)
     time_tag = time.strftime("%Y-%m-%d-%Hh%Mm", time.localtime())
     for sale_tag in ['整体平均千箱', '高价平均千箱']:
-        tag = "%s_" % sale_tag + time_tag
+        tag = "%s_%s_" % (province, sale_tag) + time_tag
         df = pd.DataFrame({sale_tag: sale_data[sale_tag]})
-        sales_mapping_file = "%s商圈OCM_%s.xlsx" % (province, sale_tag)
-        if not os.path.exists(sales_mapping_file):
-            bsp = BusinessSalesPrediction(work_dir, df, sales_file_proc, ocm_file, tag, sale_tag, sales_mapping_file, province)
-            bsp.sum_mutil_dealer(sales_file_ori)
-            bsp.ocm_pretreatment()
+        sales_mapping_file = "%s商圈OCM_%s.xlsx" % (province, sale_tag)  # sales_mapping_file为中间过度文件，经常被覆盖
+        # if not os.path.exists(sales_mapping_file):
+        bsp = BusinessSalesPrediction(work_dir, df, sales_file_proc, ocm_file, tag, sale_tag, sales_mapping_file, province)
+        bsp.ocm_pretreatment()
         ensemble_learning(work_dir, df, sales_file_proc, ocm_file, tag, sale_tag, sales_mapping_file, feature_file, province)
-        data_visualization(work_dir, tag, sale_tag)
-        AnalyzeGrading.analyze_grading(tag, '%s_综合.xlsx' % tag, '客户形态对应的商圈等级', '预估销量', '整体预估销量')
+        data_visualization(work_dir, tag, sale_tag, sales_file_proc, province)
+        AnalyzeGrading.analyze_grading(tag, '%s_综合.xlsx' % tag, '客户形态对应的商圈等级', '预估销量', '整体预估销量', province)
 
 
 if __name__ == "__main__":
